# Generated by roxygen2: do not edit by hand

export(AztekinTailData)
export(BachMammaryData)
export(BacherTCellData)
export(BaronPancreasData)
export(BhaduriOrganoidData)
export(BuettnerESCData)
export(BunisHSPCData)
export(CampbellBrainData)
export(ChenBrainData)
export(DarmanisBrainData)
export(ERCCSpikeInConcentrations)
export(ErnstSpermatogenesisData)
export(FletcherOlfactoryData)
export(GiladiHSCData)
export(GrunHSCData)
export(GrunPancreasData)
export(HeOrganAtlasData)
export(HermannSpermatogenesisData)
export(HuCortexData)
export(JessaBrainData)
export(KolodziejczykESCData)
export(KotliarovPBMCData)
export(LaMannoBrainData)
export(LawlorPancreasData)
export(LedergorMyelomaData)
export(LengESCData)
export(LunSpikeInData)
export(MacoskoRetinaData)
export(MairPBMCData)
export(MarquesBrainData)
export(MessmerESCData)
export(MuraroPancreasData)
export(NestorowaHSCData)
export(NowakowskiCortexData)
export(PaulHSCData)
export(PollenGliaData)
export(ReprocessedAllenData)
export(ReprocessedFluidigmData)
export(ReprocessedTh2Data)
export(RichardTCellData)
export(RomanovBrainData)
export(SegerstolpePancreasData)
export(ShekharRetinaData)
export(StoeckiusHashingData)
export(TasicBrainData)
export(UsoskinBrainData)
export(WuKidneyData)
export(XinPancreasData)
export(ZeiselBrainData)
export(ZeiselNervousData)
export(ZhaoImmuneLiverData)
export(ZhongPrefrontalData)
export(ZilionisLungData)
export(countErccMolecules)
export(defineTextQuery)
export(fetchDataset)
export(fetchLatestVersion)
export(fetchMetadata)
export(gsc)
export(listDatasets)
export(listPaths)
export(listVersions)
export(polishDataset)
export(saveDataset)
export(searchDatasets)
export(surveyDatasets)
import(methods)
importClassesFrom(GenomicRanges,GRangesList)
importClassesFrom(Matrix,dgCMatrix)
importClassesFrom(Matrix,lgCMatrix)
importClassesFrom(SparseArray,SVT_SparseMatrix)
importClassesFrom(alabaster.matrix,ReloadedArray)
importClassesFrom(ensembldb,EnsDb)
importFrom(AnnotationDbi,keys)
importFrom(AnnotationDbi,mapIds)
importFrom(AnnotationDbi,select)
importFrom(AnnotationHub,AnnotationHub)
importFrom(BiocGenerics,cbind)
importFrom(BiocGenerics,mean)
importFrom(DBI,dbConnect)
importFrom(DBI,dbDisconnect)
importFrom(DBI,dbGetQuery)
importFrom(DelayedArray,"type<-")
importFrom(DelayedArray,DelayedArray)
importFrom(DelayedArray,is_sparse)
importFrom(DelayedArray,type)
importFrom(ExperimentHub,ExperimentHub)
importFrom(GenomicFeatures,genes)
importFrom(RSQLite,SQLite)
importFrom(S4Vectors,"mcols<-")
importFrom(S4Vectors,DataFrame)
importFrom(SingleCellExperiment,"altExp<-")
importFrom(SingleCellExperiment,"altExps<-")
importFrom(SingleCellExperiment,"colPairs<-")
importFrom(SingleCellExperiment,"reducedDim<-")
importFrom(SingleCellExperiment,"reducedDims<-")
importFrom(SingleCellExperiment,SingleCellExperiment)
importFrom(SingleCellExperiment,altExp)
importFrom(SingleCellExperiment,altExpNames)
importFrom(SingleCellExperiment,altExps)
importFrom(SingleCellExperiment,reducedDim)
importFrom(SingleCellExperiment,reducedDimNames)
importFrom(SingleCellExperiment,splitAltExps)
importFrom(SummarizedExperiment,"assay<-")
importFrom(SummarizedExperiment,"assayNames<-")
importFrom(SummarizedExperiment,"assays<-")
importFrom(SummarizedExperiment,"colData<-")
importFrom(SummarizedExperiment,"rowData<-")
importFrom(SummarizedExperiment,"rowRanges<-")
importFrom(SummarizedExperiment,assay)
importFrom(SummarizedExperiment,assayNames)
importFrom(SummarizedExperiment,assays)
importFrom(SummarizedExperiment,colData)
importFrom(SummarizedExperiment,rowData)
importFrom(SummarizedExperiment,rowRanges)
importFrom(alabaster.base,altReadObject)
importFrom(alabaster.base,altReadObjectFunction)
importFrom(alabaster.base,readObject)
importFrom(alabaster.base,readObjectFile)
importFrom(alabaster.base,saveObject)
importFrom(gypsum,cacheDirectory)
importFrom(gypsum,defineTextQuery)
importFrom(gypsum,fetchLatest)
importFrom(gypsum,fetchMetadataDatabase)
importFrom(gypsum,fetchMetadataSchema)
importFrom(gypsum,formatObjectMetadata)
importFrom(gypsum,gsc)
importFrom(gypsum,listFiles)
importFrom(gypsum,saveFile)
importFrom(gypsum,saveVersion)
importFrom(gypsum,searchMetadataFilter)
importFrom(gypsum,translateTextQuery)
importFrom(gypsum,validateMetadata)
importFrom(jsonlite,fromJSON)
importFrom(jsonlite,toJSON)
importFrom(methods,as)
importFrom(utils,head)
importFrom(utils,read.csv)
importFrom(utils,read.delim)
importMethodsFrom(alabaster.sce,saveObject)
