write.csv(file="../extdata/2.0.0/metadata-grun-pancreas.csv",
    data.frame(
        Title = "Grun pancreas counts",
        Description = "Count matrix for the Grun pancreas single-cell RNA-seq dataset", 
        RDataPath = file.path("scRNAseq", "grun-pancreas", "2.0.0", "counts.rds"),
        BiocVersion="3.10",
        Genome="hg19",
        SourceType="TSV",
        SourceUrl="https://www.ncbi.nlm.nih.gov/geo/query/acc.cgi?acc=GSE81076",
        SourceVersion="GSE81076_D2_3_7_10_17.txt.gz",
        Species="Homo sapiens",
        TaxonomyId="9606",
        Coordinate_1_based=NA,
        DataProvider="GEO",
        Maintainer="Aaron Lun <infinite.monkeys.with.keyboards@gmail.com>",
        RDataClass="dgCMatrix",
        DispatchClass="Rds",
        stringsAsFactors = FALSE
    ),
    row.names=FALSE)
